@@ -79,6 +79,20 @@ void cmdline_completion_init()
 
 void cmdline_completion_final()
 {
+    int i;
+    for(i=0; i<vector_size(gCCandidate); i++) {
+        string_delete(vector_item(gCCandidate, i));
+    }
+    vector_delete(gCCandidate);
+    for(i=0; i<vector_size(gCExplanation); i++) {
+        string_delete(vector_item(gCExplanation, i));
+    }
+    vector_delete(gCExplanation);
+    
+    for(i=0; i<vector_size(gEnvirons); i++) {
+        string_delete(vector_item(gEnvirons, i));
+    }
+    vector_delete(gEnvirons);
 }
 
 ///////////////////////////////////////////////////
@@ -86,7 +100,14 @@ void cmdline_completion_final()
 ///////////////////////////////////////////////////
 void cmdline_completion_clear()
 {
+    int i;
+    for(i=0; i<vector_size(gCCandidate); i++) {
+        string_delete(vector_item(gCCandidate, i));
+    }
     vector_clear(gCCandidate);
+    for(i=0; i<vector_size(gCExplanation); i++) {
+        string_delete(vector_item(gCExplanation, i));
+    }
     vector_clear(gCExplanation);
 }
 
@@ -110,7 +131,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             int des_size = strlen(src)*2;
             char* des = MALLOC(des_size+1);
 #if defined(__DARWIN__)
-            if(is_all_ascii(src)) {
+            if(is_all_ascii(kByte, src)) {
                 xstrncpy(des, src, des_size);
             }
             else {
@@ -157,6 +178,12 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
         }
     }
 
+    int i;
+    for(i=0; i<vector_size(all_candidate2); i++) {
+        string_delete(vector_item(all_candidate2, i));
+    }
+    vector_delete(all_candidate2);
+
     if(vector_size(gCCandidate) > 0) {
         int l = strlen(editing);
 
@@ -335,6 +362,13 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
 
             cmdline_completion(files, editing_file, TRUE);
         }
+
+
+        int i;
+        for(i=0; i<vector_size(files); i++) {
+            string_delete(vector_item(files, i));
+        }
+        vector_delete(files);
     }
     /// not exist editing_dir ///
     else {
@@ -347,6 +381,12 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             vector_add(tilda, STRING_NEW("~/"));
 
             cmdline_completion(tilda, editing, TRUE);
+
+            int i;
+            for(i=0; i<vector_size(tilda); i++) {
+                string_delete(vector_item(tilda, i));
+            }
+            vector_delete(tilda);
         }
         else {
             DIR* dir = opendir(".");
@@ -376,6 +416,12 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
 
                 vector_sort(files, name_sort);
                 cmdline_completion(files, editing_file, TRUE);
+
+                int i;
+                for(i=0; i<vector_size(files); i++) {
+                    string_delete(vector_item(files, i));
+                }
+                vector_delete(files);
             }
         }
     }
@@ -415,6 +461,11 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
+
+        for(i=0; i<vector_size(new_candidate); i++) {
+            string_delete(vector_item(new_candidate, i));
+        }
+        vector_delete(new_candidate);
     }
     else if(*editing == '$' && *(editing+1) =='$') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -430,6 +481,11 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
+
+        for(i=0; i<vector_size(new_candidate); i++) {
+            string_delete(vector_item(new_candidate, i));
+        }
+        vector_delete(new_candidate);
     }
     else if(*editing == '@' && *(editing+1) !='@') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -445,6 +501,11 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
+
+        for(i=0; i<vector_size(new_candidate); i++) {
+            string_delete(vector_item(new_candidate, i));
+        }
+        vector_delete(new_candidate);
     }
     else if(*editing == '@' && *(editing+1) =='@') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -460,6 +521,11 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
+
+        for(i=0; i<vector_size(new_candidate); i++) {
+            string_delete(vector_item(new_candidate, i));
+        }
+        vector_delete(new_candidate);
     }
 }
 
@@ -552,6 +618,10 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             xstrncpy(cmdname, "", kCmdLineMax);
             *editing_position = 0;
+            int i;
+            for(i=0; i<vector_size(*earray); i++) {
+                string_delete(vector_item(*earray, i));
+            }
             vector_clear(*earray);
  
             while(*p && *p == ' ') p++;
@@ -577,6 +647,12 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
         *last_dquote = TRUE;
     }
 
+    int i;
+    for(i=0; i<vector_size(*earray); i++) {
+        string_delete(vector_item(*earray, i));
+    }
+    vector_delete(*earray);
+
     /// divide editing into dir part and file part ///
     xstrncpy(editing_dir, "", kCmdLineMax);
     xstrncpy(editing_file, "", kCmdLineMax);
