@@ -164,7 +164,7 @@ static void input_box_cursor_move(string_obj* input, int* cursor, int v)
 }
 
 char* gInputBoxMsg;
-string_obj* gInputBoxInput;
+string_obj* gInputBoxInput = NULL;
 int gInputBoxCursor;
     
 void input_box_view()
@@ -197,6 +197,7 @@ int input_box(char* msg, char* result, int result_size, char* def_input, int def
     int result2 = 0;
     gInputBoxCursor = def_cursor;
 
+    if(gInputBoxInput) string_delete(gInputBoxInput);
     gInputBoxInput = STRING_NEW(def_input);
     
     gView = input_box_view;
