@@ -270,6 +270,8 @@ static BOOL match_next(int start)
                 }
                 migemo_release(gMigemo, (unsigned char*) p);
 
+                FREE(p2);
+
                 if(r != ONIG_NORMAL) {
                     return FALSE;
                 }
@@ -442,6 +444,7 @@ void isearch_final()
 
             it = hash_loop_next(it);
         }
+        hash_delete(gMigemoCache);
     }
 #endif
 
